# wm_dist
## About
Calculates distances from points on vertex mesh through a volume. Distances are calculated by solving Eikonal equation.

## Installation
python3 setup.py install 

## Useage

### Example
python3 wm_dist.py --classified "cls.mnc" --surface "mid.obj" --label 3 --matrix "matrix.csv" --max-threads 4 --subsample "5,4" 




 
